@@ -476,6 +476,65 @@ class standard_custodian_table:
 
         return data
 
+    def mode8(self, filepath):
+        xls = pd.read_excel(filepath, header=None)
+        data = {}
+        print(xls)
+        data['fund_name'] = xls.loc[2, 0].split("_")[1]
+        data['inner_date'] = gt.find_date(xls.loc[0, 0])
+
+        header1 = xls.loc[5, :]
+        header2 = xls.loc[6, :]
+        header = []
+        for i in range(len(header1)):
+            if header1[i] == header2[i]:
+                header.append(header1[i])
+            else:
+                header.append(header1[i] + "-" + header2[i])
+        last_idx = (xls.isnull().sum(axis=1) == xls.shape[1])\
+            .loc[lambda x: x == True].index[-2]  # noqa: E712
+        df = xls[7:last_idx].copy().reset_index(drop=True)
+        df.columns = header
+        m = self.MODEs["mode2"]
+        h = dict(zip(m['header'], m['header'].index))
+        df = df.rename(columns=h)[list(h.values())]
+        df['account_code'] = df['account_code'].apply(
+            lambda x: str(x).split(" ")[0].replace(".", ""))
+        df['date'] = data["inner_date"]
+        data['raw'] = df.copy()
+
+        c = m['code_map'].dropna(subset=['含标的'])
+        underlyings = pd.DataFrame()
+        for item in c['资产类别'].drop_duplicates():
+            unit = df[df['account_code'].apply(
+                lambda x:
+                    len(x) > 8
+                    and
+                    x[:8] in list(c[c['资产类别'] == item]['account_code'])
+            )].copy()
+            unit['level3_code'] = unit['account_code'].apply(lambda x: x[:8])
+            unit['code'] = unit['account_code'].apply(lambda x: x[8:])
+            unit['asset_class'] = item
+            underlyings = pd.concat([underlyings, unit], ignore_index=True)
+
+        underlyings['date'] = data['inner_date']
+        underlyings['fund_name'] = data['fund_name']
+        underlyings.columns.name = None
+        data['main_body'] = underlyings
+
+        data['shares'] = float(
+            xls.loc[(xls[0].loc[lambda x: x == "实收资本"]).index[0], 4])
+        data['total_assets'] = float(
+            xls.loc[(xls[0].loc[lambda x: x == "资产合计"]).index[0], 9])
+        data['total_liabilities'] = float(
+            xls.loc[(xls[0].loc[lambda x: x == "负债合计"]).index[0], 9])
+        data['nav'] = float(
+            xls.loc[(xls[0].loc[lambda x: x == "单位净值"]).index[0], 1])
+        data['cum_nav'] = float(
+            xls.loc[(xls[0].loc[lambda x: x == "累计单位净值"]).index[0], 1])
+
+        return data
+
 
 if __name__ == '__main__':
     pass
